@@ -68,47 +68,33 @@
 import os
 import sys
 import logging
-from logging.handlers import SocketHandler,SysLogHandler
 
-from hubzero.submit.JobDistributor import JobDistributor
+from hubzero.submit.ApplicationUtilities import ApplicationUtilities as ApplicationUtilities
+from hubzero.submit.JobDistributor       import JobDistributor
 
-LOGDIRECTORY      = os.path.join(os.sep,'var','log','submit','distributor')
-APPLICATIONLOGGER = logging.getLogger('')
+DISTRIBUTORLOGLEVEL    = "INFO"
+DISTRIBUTORSYSLOGLOCAL = "LOCAL3"
 
+#DISTRIBUTORLOGDIRECTORY = os.path.join(os.sep,'var','log','submit','distributor')
 CONFIGURATIONDIRECTORY       = os.path.join(os.sep,'etc','submit')
 DISTRIBUTORCONFIGURATIONFILE = 'distributor.conf'
+DAEMONSDIRECTORY             = os.path.join(os.sep,"etc","submit")
 DAEMONSCONFIGURATIONFILE     = 'daemons.conf'
+INFOSDIRECTORY               = os.path.join(os.sep,"etc","submit")
 INFOSCONFIGURATIONFILE       = 'infos.conf'
 
-def openLogger():
-   class EmptyFilter(logging.Filter):
-      """
-      This is a filter which rejects empty messages
-
-      """
-
-      def filter(self,record):
-         if record.getMessage() == "":
-            emptyRecord = True
-         else:
-            emptyRecord = False
-
-         return(not emptyRecord)
-
-   APPLICATIONLOGGER.setLevel(logging.DEBUG)
-
-   logSyslogHandler = SysLogHandler(address="/dev/log",facility=SysLogHandler.LOG_LOCAL3)
-   emptyFilter = EmptyFilter()
-   logSyslogHandler.addFilter(emptyFilter)
-   logFormatter = logging.Formatter('%(asctime)s %(message)s','%s [%a %b %d %H:%M:%S %Y]')
-   logSyslogHandler.setFormatter(logFormatter)
-   APPLICATIONLOGGER.addHandler(logSyslogHandler)
-
-
 def distributor(configurationDirectory,
-                distributorConfigurationFile,daemonsConfigurationFile,infosConfigurationFile):
+                distributorConfigurationFile,
+                daemonsDirectory,
+                daemonsConfigurationFile,
+                infosDirectory,
+                infosConfigurationFile):
    jobDistributor = JobDistributor(configurationDirectory,
-                                   distributorConfigurationFile,daemonsConfigurationFile,infosConfigurationFile)
+                                   distributorConfigurationFile,
+                                   daemonsDirectory,
+                                   daemonsConfigurationFile,
+                                   infosDirectory,
+                                   infosConfigurationFile)
    if jobDistributor.configure():
       exitCode = jobDistributor.processCommandArguments()
       if not exitCode:
@@ -124,9 +110,23 @@ def distributor(configurationDirectory,
 
 
 if __name__ == '__main__':
-   openLogger()
+   distributorLogLevel          = os.getenv("DISTRIBUTORLOGLEVEL",DISTRIBUTORLOGLEVEL)
+   distributorSysLogLocal       = os.getenv("DISTRIBUTORSYSLOGLOCAL",DISTRIBUTORSYSLOGLOCAL)
+   configurationDirectory       = os.getenv("CONFIGURATIONDIRECTORY",CONFIGURATIONDIRECTORY)
+   distributorConfigurationFile = os.getenv("DISTRIBUTORCONFIGURATIONFILE",DISTRIBUTORCONFIGURATIONFILE)
+   daemonsDirectory             = os.getenv("DAEMONSDIRECTORY",DAEMONSDIRECTORY)
+   daemonsConfigurationFile     = os.getenv("DAEMONSCONFIGURATIONFILE",DAEMONSCONFIGURATIONFILE)
+   infosDirectory               = os.getenv("INFOSDIRECTORY",INFOSDIRECTORY)
+   infosConfigurationFile       = os.getenv("INFOSCONFIGURATIONFILE",INFOSCONFIGURATIONFILE)
 
-   distributor(CONFIGURATIONDIRECTORY,
-               DISTRIBUTORCONFIGURATIONFILE,DAEMONSCONFIGURATIONFILE,INFOSCONFIGURATIONFILE)
+   applicationUtilities = ApplicationUtilities(DISTRIBUTORLOGLEVEL,
+                                               DISTRIBUTORSYSLOGLOCAL)
+
+   applicationUtilities.openSysLogLogger(distributorSysLogLocal,
+                                         distributorLogLevel)
+
+   distributor(configurationDirectory,distributorConfigurationFile,
+               daemonsDirectory,daemonsConfigurationFile,
+               infosDirectory,infosConfigurationFile)
 
 
