@@ -300,7 +300,8 @@ class HarvestLocal(HarvestCore):
                                                     remoteScratchDirectory + " " + \
                                                     self.remoteBatchSystem
                   self.logger.log(logging.INFO,getLogMessage("command = " + command))
-                  self.logger.log(logging.INFO,getLogMessage(self.executeCommand(command)[1]))
+                  exitStatus,stdOutput,stdError = self.executeCommand(command)
+                  self.logger.log(logging.INFO,getLogMessage(stdOutput))
 
             workDirectoryName = os.path.join(self.instanceDirectory,'work')
             if os.path.isdir(workDirectoryName):
@@ -324,7 +325,8 @@ class HarvestLocal(HarvestCore):
                                                  remoteScratchDirectory + " " + \
                                                  self.remoteBatchSystem
                self.logger.log(logging.INFO,getLogMessage("command = " + command))
-               self.logger.log(logging.INFO,getLogMessage(self.executeCommand(command)[1]))
+               exitStatus,stdOutput,stdError = self.executeCommand(command)
+               self.logger.log(logging.INFO,getLogMessage(stdOutput))
 
          if self.removeIdentity:
             if os.path.isfile(self.sshIdentityPath):
