@@ -71,6 +71,9 @@ class RemoteWorkflowPEGASUS:
                 sshIdentityPath,
                 gridsite,
                 pegasusSiteInfo,
+                nGpus,
+                gpn,
+                memoryMB,
                 wallTime,
                 siteInfo,
                 submissionScriptsInfo,
@@ -104,6 +107,9 @@ class RemoteWorkflowPEGASUS:
       self.sshIdentityPath          = sshIdentityPath
       self.gridsite                 = gridsite
       self.pegasusSiteInfo          = pegasusSiteInfo
+      self.nGpus                    = nGpus
+      self.gpn                      = gpn
+      self.memoryMB                 = memoryMB
       self.wallTime                 = wallTime
       self.submissionScriptCommands = siteInfo['submissionScriptCommands']
       self.timePaths                = siteInfo['timePaths']
@@ -190,7 +196,8 @@ class RemoteWorkflowPEGASUS:
          submissionScript = template.substitute_recur(substitutions)
       except KeyError as e:
          submissionScript = ""
-         self.logger.log(logging.ERROR,getLogMessage("Pattern substitution failed for @@%s\n" % (e.args[0])))
+         self.logger.log(logging.ERROR,getLogMessage("Pattern substitution failed for @@{%s}\n" % (e.args[0])))
+         self.logger.log(logging.ERROR,getLogMessage("in SubmissionScripts/Distributor/Workflow/PEGASUS/plan\n"))
       except TypeError:
          submissionScript = ""
          self.logger.log(logging.ERROR,getLogMessage("Submission script substitution failed:\n%s\n" % (rawSubmissionScript)))
@@ -220,6 +227,7 @@ class RemoteWorkflowPEGASUS:
          substitutions["X509SUBMITPROXY"]   = os.path.join(os.sep,'tmp','hub-proxy.%s' % (self.hubUserName))
       substitutions["PEGASUSHOME"]          = self.pegasusHome
       substitutions["SSHPRIVATEKEYPATH"]    = self.sshIdentityPath
+      substitutions["MEMORY"]               = self.memoryMB
 
       for templateType in self.pegasusTemplates:
          pegasusTemplatePath = self.pegasusTemplates[templateType]
@@ -242,7 +250,8 @@ class RemoteWorkflowPEGASUS:
                      pegasusText = pegasusTemplate.substitute_recur(substitutions)
                   except KeyErroras as e:
                      pegasusText = ""
-                     self.logger.log(logging.ERROR,getLogMessage("Pattern substitution failed for @@%s\n" % (e.args[0])))
+                     self.logger.log(logging.ERROR,getLogMessage("Pattern substitution failed for @@{%s}\n" % (e.args[0])))
+                     self.logger.log(logging.ERROR,getLogMessage("in %s\n" % (pegasusTemplatePath)))
                   except TypeError:
                      pegasusText = ""
                      self.logger.log(logging.ERROR,getLogMessage("Pegasus template substitution failed:\n%s\n" % (template)))
